public inbox for linux-kernel@vger.kernel.org
 help / color / mirror / Atom feed
* [PATCH] fix saa7146 compilation on 2.6.8-rc1
@ 2004-07-12  8:25 colin
  2004-07-12 15:20 ` Geert Uytterhoeven
  2004-07-12 19:47 ` Michael Hunold
  0 siblings, 2 replies; 5+ messages in thread
From: colin @ 2004-07-12  8:25 UTC (permalink / raw)
  To: michael; +Cc: linux-kernel

Hi,
this patch fixes a compilation error on 2.6.8-rc1. Here's the error:
drivers/media/common/saa7146_video.c:3: conflicting types for `memory'
include/asm-m68k/setup.h:365: previous declaration of `memory'
make[3]: *** [drivers/media/common/saa7146_video.o] Error 1

hth.

Signed-off-by: Colin Leroy <colin@colino.net>

--- a/drivers/media/common/saa7146_video.c	2004-07-12 10:15:51.833352344 +0200
+++ b/drivers/media/common/saa7146_video.c	2004-07-12 10:16:21.209886432 +0200
@@ -1,9 +1,9 @@
 #include <media/saa7146_vv.h>
 
-static int memory = 32;
+static int max_memory = 32;
 
-MODULE_PARM(memory,"i");
-MODULE_PARM_DESC(memory, "maximum memory usage for capture buffers (default: 32Mb)");
+MODULE_PARM(max_memory,"i");
+MODULE_PARM_DESC(max_memory, "maximum memory usage for capture buffers (default: 32Mb)");
 
 #define IS_CAPTURE_ACTIVE(fh) \
 	(((vv->video_status & STATUS_CAPTURE) != 0) && (vv->video_fh == fh))
@@ -1331,9 +1331,9 @@
 
 	*size = fh->video_fmt.sizeimage;
 
-	/* check if we exceed the "memory" parameter */
-	if( (*count * *size) > (memory*1048576) ) {
-		*count = (memory*1048576) / *size;
+	/* check if we exceed the "max_memory" parameter */
+	if( (*count * *size) > (max_memory*1048576) ) {
+		*count = (max_memory*1048576) / *size;
 	}
 	
 	DEB_CAP(("%d buffers, %d bytes each.\n",*count,*size));


^ permalink raw reply	[flat|nested] 5+ messages in thread

end of thread, other threads:[~2004-07-12 19:47 UTC | newest]

Thread overview: 5+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2004-07-12  8:25 [PATCH] fix saa7146 compilation on 2.6.8-rc1 colin
2004-07-12 15:20 ` Geert Uytterhoeven
2004-07-12 15:31   ` Colin LEROY
2004-07-12 15:40     ` Geert Uytterhoeven
2004-07-12 19:47 ` Michael Hunold

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox